@@ -4,9 +4,10 @@ import requests
 import logging
 
 from requests.exceptions import SSLError
+from pathlib import Path
 
 test_url = "https://design.dataiku.vestas.net/"
-certificate_dir = "./certificates"
+certificate_dir = os.path.join(Path(__file__).parent, "certificates")
 
 
 def add_certificates():
